=========
Messaging
=========


``ploneintranet.messaging`` provides a simple bilateral (one user to another user) chat-like messaging system.


Limitations
-----------

Foreseen, but not yet implemented:

* Push messages / web socket for real-time chat
* Multi-user chat groups
* Richer message model with file/image attachments, tags etc.
